<?php


namespace Schaffen\Core\Movement\Managers;


use Carbon\Carbon;
use Freelabois\LaravelQuickstart\Extendables\ManipulationManager;
use Illuminate\Support\Facades\DB;
use Schaffen\Core\Movement\Repositories\InventoryControlSchedulingRepository;

class InventoryControlSchedulingManager extends ManipulationManager
{

    protected $repository;

    public function __construct(InventoryControlSchedulingRepository $repository)
    {
        $this->repository = $repository;
    }

    public function storeOrUpdate($values, int $id = NULL, $relations = [])
    {
        return DB::transaction(function () use ($values, $id, $relations) {
            if (isset($values['pee_padrao']) && $values['pee_padrao'] === 1) {
                $pes_codigo = NULL;
                if (isset($values['pee_fk_pes_codigo'])) {
                    $pes_codigo = $values['pee_fk_pes_codigo'];
                }
                if (!$pes_codigo && $id) {
                    $pes_codigo = $this->repository->setSelect(['pee_fk_pes_codigo'])
                        ->find($id)->pee_fk_pes_codigo;
                }
                $query = $this->repository->newQuery();
                $query->where('pee_fk_pes_codigo', $pes_codigo)
                    ->where('pee_padrao', '=', 1)
                    ->update(['pee_padrao' => 0]);
            }
            return parent::storeOrUpdate($values, $id, $relations);
        });
    }

    public function getScheduling()
    {
        $user = auth()->user();
        return $this->repository->newQuery()
            ->select(['agc_codigo', 'agc_fk_fil_codigo', 'agc_fk_pes_codigo', 'agc_fk_mvf_codigo', 'agc_tipo_contagem',
                'agc_perc_divergencia', 'pes_nome', 'fil_descricao', 'loe_descricao', 'agc_status', 'agc_fk_loe_codigo',
                'agc_data_contagem'])
            ->join('movimentacao.local_estoque', "loe_codigo", "=", "agc_fk_loe_codigo")
            ->join('cadastro.pessoa', 'pes_codigo', '=', 'agc_fk_pes_codigo')
            ->join('cadastro.filial', 'fil_codigo', '=', 'agc_fk_fil_codigo')
            ->where('agc_data_contagem', '>=', Carbon::now())
            ->where('agc_data_contagem', '<=', Carbon::now()->addDays(15))
            ->where('agc_fk_pes_codigo', '=', $user->usu_fk_pes_codigo)
            ->whereIn('agc_status', [0, 1])
            ->whereNull('deleted_at')
            ->orderBy('agc_data_contagem', 'ASC')
            ->get();

    }
}
